==> nextcloud-app-news-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/es_AR.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Se presentó una falla en la solicitud. ¡La conexión a la red no está disponible!",
    "Request unauthorized. Are you logged in?" : "Solicitud rechazada. ¿Ha iniciado sesisón?",
    "Request forbidden. Are you an admin?" : "Solicitud prohibida. ¿Es usted un adminsitrador?",
    "Token expired or app not enabled! Reload the page!" : "¡La ficha expiró o la aplicación no está habilitada! ¡Favor de recargar la página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "¡Se presentó un error interno del servidor! ¡Favor de verificar el archivo data/nextcloud.log para más informacón!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "¡Se presentó una falla, por el momento Nextcloud se encuentra en modo mantenimiento!",
    "Unread articles" : "Artículos sin leer",
    "News" : "Noticias",
    "Shared with me" : "Compartido conmigo",
    "An RSS/Atom feed reader" : "Un lector de feeds RSS/Atom",
    "Use system cron for updates" : "Use el sistema cron para las actualizaciones",
    "Purge interval" : "Purgar el intervalo",
    "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
    "Maximum redirects" : "Redirecciones máximas",
    "Feed fetcher timeout" : "Tiempo de espera máximo para el buscador de fuentes",
    "Explore Service URL" : "Explorar la URL del Servicio",
    "Saved" : "Guardado",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "No articles available" : "No hay artículos disponibles",
    "No unread articles available" : "No hay artículos sin leer disponibles",
    "Open website" : "Abrir sitio web",
    "Star article" : "Marcar el artículo",
    "Unstar article" : "Desmarcar artículo",
    "Keep article unread" : "Mantener el artículo como no-leído",
    "Remove keep article unread" : "Eliminar mantener artículo como no leído",
    "Share" : "Compartir",
    "Username" : "Nombre de usuario",
    "by" : "por",
    "from" : "de",
    "Play audio" : "Reproducir audio",
    "Download audio" : "Descargar audio",
    "Download video" : "Descargar video",
    "Keyboard shortcut" : "Atajo del teclado",
    "Description" : "Descripción",
    "right" : "derecha",
    "Jump to next article" : "Ir al artículo siguiente ",
    "left" : "izquierda",
    "Jump to previous article" : "Ir al artículo anterior",
    "Toggle star article" : "Alternar artículos marcados",
    "Star article and jump to next one" : "Marcar el artículo y continuar al siguiente",
    "Toggle keep current article unread" : "Alternar mantener artículo actual como no leído",
    "Open article in new tab" : "Abrir el artículo en una nueva pestaña",
    "Toggle expand article in compact view" : "Alternar expandir artículo en vista compacta",
    "Refresh" : "Actualizar",
    "Load next feed" : "Cargar fuente siguiente",
    "Load previous feed" : "Cargar fuente anterior",
    "Load previous folder" : "Cargar carpeta anterrior",
    "Load next folder" : "Cargar la siguiente carpeta",
    "Scroll to active navigation entry" : "Desplácese hasta el elemento de navegación activo",
    "Mark current article's feed/folder read" : "Marcar la fuente/carpeta del artículo actual como leído",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Se detectó el modo Ajax o webcron! Tus feeds no serán actualizados!",
    "How to set up the operating system cron" : "Como establecer las tareas programadas del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale y configure un actualizador en paralelo más rápido que use el API de actualización de la nueva aplicación",
    "Subscribe" : "Suscribir",
    "Web address" : "Dirección web",
    "Feed exists already!" : "¡La fuente ya existe!",
    "Folder" : "Carpeta",
    "No folder" : "No hay carpetas",
    "New folder" : "Carpeta nueva ",
    "Folder name" : "Nombre de la carpeta",
    "Go back" : "Regresar",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "Credentials" : "Credenciales",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales HTTP Basic Auth deben ser almacenadas decriptadas! ¡Todos aquellos que tengan acceso al servidor o a la base de datos tendrán acceso a ellas!",
    "Password" : "Contraseña",
    "New Folder" : "Carpeta Nueva",
    "Create" : "Crear",
    "Explore" : "Explorar",
    "Update failed more than 50 times" : "La carga falló más de 50 veces",
    "Deleted feed" : "Borrar fuente",
    "Undo delete feed" : "Deshacer borrar fuente",
    "Rename" : "Renombrar",
    "Menu" : "Menú",
    "Mark read" : "Marcar como leído",
    "Unpin from top" : "Desanclar a la parte superior",
    "Pin to top" : "Anclar a la parte superior",
    "Newest first" : "Más reciente primero",
    "Oldest first" : "Más antiguo primero",
    "Default order" : "Ordenamiento predeterminado",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "Unread updated" : "No-leídos actualizados",
    "Ignore updated" : "Ignorar actualizados",
    "Open feed URL" : "Abrir URL de feed",
    "Delete" : "Borrar",
    "Dismiss" : "Descartar",
    "Collapse" : "Colapsar",
    "Deleted folder" : "Borrar carpeta",
    "Undo delete folder" : "Deshacer borrar carpeta",
    "Starred" : "Marcados",
    "All articles" : "Todos los artículos",
    "Settings" : "Configuraciones ",
    "Disable mark read through scrolling" : "Deshabilitar el marcar como leído al desplazar",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Expandir artículos al navegar con el teclado",
    "Show all articles" : "Mostrar todos los artículos",
    "Reverse ordering (oldest on top)" : "Orden inverso (más antiguo arriba)",
    "Subscriptions (OPML)" : "Subscripciones (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: File does not contain valid OPML" : "Se presentó un error al importar: El archivo no contiene un OPML válido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Se presentó un error al importar: OPML no contiene fuentes o carpetas",
    "Unread/Starred Articles" : "Artículos No Leídos/Marcados",
    "Error when importing: file does not contain valid JSON" : "Se presentó un error al importar: el archivo no contiene un JSON válido",
    "Help" : "Ayuda",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Documentation" : "Documentación",
    "Report a bug" : "Reportar una falla"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-news-18.1.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/news/l10n/es_AR.js <==
OC.L10N.register(
    "news",
    {
    "Request failed, network connection unavailable!" : "Se presentó una falla en la solicitud. ¡La conexión a la red no está disponible!",
    "Request unauthorized. Are you logged in?" : "Solicitud rechazada. ¿Ha iniciado sesisón?",
    "Request forbidden. Are you an admin?" : "Solicitud prohibida. ¿Es usted un adminsitrador?",
    "Token expired or app not enabled! Reload the page!" : "¡La ficha expiró o la aplicación no está habilitada! ¡Favor de recargar la página!",
    "Internal server error! Please check your data/nextcloud.log file for additional information!" : "¡Se presentó un error interno del servidor! ¡Favor de verificar el archivo data/nextcloud.log para más informacón!",
    "Request failed, Nextcloud is in currently in maintenance mode!" : "¡Se presentó una falla, por el momento Nextcloud se encuentra en modo mantenimiento!",
    "Unread articles" : "Artículos sin leer",
    "News" : "Noticias",
    "Shared with me" : "Compartido conmigo",
    "An RSS/Atom feed reader" : "Un lector de feeds RSS/Atom",
    "Use system cron for updates" : "Use el sistema cron para las actualizaciones",
    "Purge interval" : "Purgar el intervalo",
    "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
    "Maximum redirects" : "Redirecciones máximas",
    "Feed fetcher timeout" : "Tiempo de espera máximo para el buscador de fuentes",
    "Explore Service URL" : "Explorar la URL del Servicio",
    "Saved" : "Guardado",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "No articles available" : "No hay artículos disponibles",
    "No unread articles available" : "No hay artículos sin leer disponibles",
    "Open website" : "Abrir sitio web",
    "Star article" : "Marcar el artículo",
    "Unstar article" : "Desmarcar artículo",
    "Keep article unread" : "Mantener el artículo como no-leído",
    "Remove keep article unread" : "Eliminar mantener artículo como no leído",
    "Share" : "Compartir",
    "Username" : "Nombre de usuario",
    "by" : "por",
    "from" : "de",
    "Play audio" : "Reproducir audio",
    "Download audio" : "Descargar audio",
    "Download video" : "Descargar video",
    "Keyboard shortcut" : "Atajo del teclado",
    "Description" : "Descripción",
    "right" : "derecha",
    "Jump to next article" : "Ir al artículo siguiente ",
    "left" : "izquierda",
    "Jump to previous article" : "Ir al artículo anterior",
    "Toggle star article" : "Alternar artículos marcados",
    "Star article and jump to next one" : "Marcar el artículo y continuar al siguiente",
    "Toggle keep current article unread" : "Alternar mantener artículo actual como no leído",
    "Open article in new tab" : "Abrir el artículo en una nueva pestaña",
    "Toggle expand article in compact view" : "Alternar expandir artículo en vista compacta",
    "Refresh" : "Actualizar",
    "Load next feed" : "Cargar fuente siguiente",
    "Load previous feed" : "Cargar fuente anterior",
    "Load previous folder" : "Cargar carpeta anterrior",
    "Load next folder" : "Cargar la siguiente carpeta",
    "Scroll to active navigation entry" : "Desplácese hasta el elemento de navegación activo",
    "Mark current article's feed/folder read" : "Marcar la fuente/carpeta del artículo actual como leído",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Se detectó el modo Ajax o webcron! Tus feeds no serán actualizados!",
    "How to set up the operating system cron" : "Como establecer las tareas programadas del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale y configure un actualizador en paralelo más rápido que use el API de actualización de la nueva aplicación",
    "Subscribe" : "Suscribir",
    "Web address" : "Dirección web",
    "Feed exists already!" : "¡La fuente ya existe!",
    "Folder" : "Carpeta",
    "No folder" : "No hay carpetas",
    "New folder" : "Carpeta nueva ",
    "Folder name" : "Nombre de la carpeta",
    "Go back" : "Regresar",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "Credentials" : "Credenciales",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales HTTP Basic Auth deben ser almacenadas decriptadas! ¡Todos aquellos que tengan acceso al servidor o a la base de datos tendrán acceso a ellas!",
    "Password" : "Contraseña",
    "New Folder" : "Carpeta Nueva",
    "Create" : "Crear",
    "Explore" : "Explorar",
    "Update failed more than 50 times" : "La carga falló más de 50 veces",
    "Deleted feed" : "Borrar fuente",
    "Undo delete feed" : "Deshacer borrar fuente",
    "Rename" : "Renombrar",
    "Menu" : "Menú",
    "Mark read" : "Marcar como leído",
    "Unpin from top" : "Desanclar a la parte superior",
    "Pin to top" : "Anclar a la parte superior",
    "Newest first" : "Más reciente primero",
    "Oldest first" : "Más antiguo primero",
    "Default order" : "Ordenamiento predeterminado",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "Unread updated" : "No-leídos actualizados",
    "Ignore updated" : "Ignorar actualizados",
    "Open feed URL" : "Abrir URL de feed",
    "Delete" : "Borrar",
    "Dismiss" : "Descartar",
    "Collapse" : "Colapsar",
    "Deleted folder" : "Borrar carpeta",
    "Undo delete folder" : "Deshacer borrar carpeta",
    "Starred" : "Marcados",
    "All articles" : "Todos los artículos",
    "Settings" : "Configuraciones ",
    "Disable mark read through scrolling" : "Deshabilitar el marcar como leído al desplazar",
    "Compact view" : "Vista compacta",
    "Expand articles on key navigation" : "Expandir artículos al navegar con el teclado",
    "Show all articles" : "Mostrar todos los artículos",
    "Reverse ordering (oldest on top)" : "Orden inverso (más antiguo arriba)",
    "Subscriptions (OPML)" : "Subscripciones (OPML)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Error when importing: File does not contain valid OPML" : "Se presentó un error al importar: El archivo no contiene un OPML válido",
    "Error when importing: OPML is does neither contain feeds nor folders" : "Se presentó un error al importar: OPML no contiene fuentes o carpetas",
    "Unread/Starred Articles" : "Artículos No Leídos/Marcados",
    "Error when importing: file does not contain valid JSON" : "Se presentó un error al importar: el archivo no contiene un JSON válido",
    "Help" : "Ayuda",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Documentation" : "Documentación",
    "Report a bug" : "Reportar una falla"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
